@@ -1,5 +1,5 @@
 chooseGpu <- function(deviceId = 0) 
 {
 	deviceId <- as.integer(deviceId)
-	.C("rsetDevice", deviceId)
+	.C("rsetDevice", deviceId, PACKAGE='gputools')
 }
