@@ -39,7 +39,8 @@ extern "C" {
 	void RpermHostKendall(const float * X, const int * nx, const float * Y, 
 		const int * ny, const int * sampleSize, double * answers);
 	void RgpuKendall(const float * X, const int * nx, const float * Y, 
-		const int * ny, const int * sampleSize, double * answers);
+                   const int * ny, const int * sampleSize, double * answers,
+                   const char ** kernel_src);
 
 	void rgpuGranger(const int * rows, const int * colsy, const float * y, 
 		const int * p, float * fStats, float * pValues);
